@@ -6,8 +6,7 @@
 */
 
 
-#ifndef MAINWINDOW_H
-#define MAINWINDOW_H
+#pragma once
 
 #include <QMainWindow>
 
@@ -71,4 +70,3 @@ class MainWindow : public QMainWindow
 
 };
 
-#endif // MAINWINDOW_H
